# LionAGI Code of Conduct

## A. Our Pledge

In the interest of fostering an open and welcoming environment, we as members, contributors, and leaders of the LionAGI community pledge to make participation in our project and our community a harassment-free experience for everyone, regardless of background, identity, and personal characteristics.

We commit to act and interact in ways that contribute to an inclusive, diverse, and friendly community.

## B. Our Standards

Examples of behavior that contribute to a positive environment include:

* Demonstrating empathy and kindness toward other people.
* Being respectful of differing opinions, viewpoints, and experiences.
* Giving and gracefully accepting constructive feedback.
* Accepting responsibility for our actions, apologizing to those affected by our mistakes, and learning from the experience.
* Focusing on what is best for the community as a whole.

Examples of unacceptable behavior include:

* The use of sexualized language or imagery, and sexual attention or advances of any kind.
* Trolling, insulting or derogatory comments, and personal or political attacks.
* Public or private harassment.
* Publishing others' private information, such as a physical or email address, without explicit permission.
* Other conduct which could reasonably be considered inappropriate in a professional setting.

## C. Enforcement Responsibilities

Our community leaders are responsible for clarifying the standards of acceptable behavior and are expected to take appropriate and fair corrective action in response to any instances of unacceptable behavior.

Community leaders have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned with this Code of Conduct.

## D. Scope

This Code of Conduct applies within all community spaces, including GitHub, Discord, and various social media platforms, and also applies when an individual is officially representing the community.

## E. Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported by contacting the project team via our Discord server. All complaints will be reviewed and investigated in a manner that ensures fairness and respect for all parties.

Community leaders are obligated to respect the privacy and security of the reporter of any incident.

## F. Enforcement Guidelines

Community leaders will follow these Community Impact Guidelines in determining the consequences for any action deemed in violation of this Code of Conduct:

### 1. Correction

**Community Impact**: Use of inappropriate language or behavior deemed unprofessional.

**Consequence**: A private written warning from community leaders, with an explanation of why the behavior was inappropriate.

### 2. Warning

**Community Impact**: A violation through a single incident or series of actions.

**Consequence**: A warning with consequences for continued behavior. This includes a temporary ban from community interaction if the behavior persists.

### 3. Temporary Ban

**Community Impact**: A serious violation of community standards.

**Consequence**: A temporary ban from any sort of interaction within the community.

### 4. Permanent Ban

**Community Impact**: Sustained inappropriate behavior, harassment, or aggression toward individuals.

**Consequence**: A permanent ban from any sort of public interaction within the community.

## G. Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.0, available at [Contributor Covenant](https://www.contributor-covenant.org/version/2/0/code_of_conduct.html).

For answers to common questions about this code of conduct, see the [FAQ](https://www.contributor-covenant.org/faq).
